@@ -1,9 +1,9 @@
-context("classif_h2oglm")
 
 test_that("classif_h2oglm", {
   skip_on_ci()
   requirePackages("h2o", default.method = "load")
-  h2o::h2o.init()
+  h2o::h2o.no_progress()
+  foo = capture.output(h2o::h2o.init())
 
   parset.list = list(
     list(),
@@ -50,11 +50,10 @@ test_that("feature importances are returned", {
 
   lrn = makeLearner("classif.h2o.glm")
   mod = train(lrn, task)
-  feat.imp = getFeatureImportance(mod)$res
+  feat.imp = as.data.frame(getFeatureImportance(mod)$res)
   feat.imp.h2o = na.omit(h2o::h2o.varimp(getLearnerModel(mod))[, c("variable", "relative_importance")])
-  # Convert to data.frame with same structure for equality check
-  feat.imp.h2o = data.frame(as.list(xtabs(relative_importance ~ variable,
-    data = feat.imp.h2o)))[names(feat.imp)]
+  names(feat.imp) = names(feat.imp.h2o)
+  feat.imp = feat.imp[order(feat.imp$relative_importance, decreasing = TRUE), ]
 
-  expect_equal(feat.imp, feat.imp.h2o)
+  expect_equal(feat.imp, feat.imp.h2o, ignore_attr = c("row.names", "class"))
 })
