@@ -1,12 +1,11 @@
-context("cluster_XMeans")
 
 test_that("cluster_XMeans", {
   skip_on_os("windows")
   skip_on_cran()
 
   requirePackagesOrSkip("RWeka", default.method = "load")
-  # RWeka::WPM("refresh-cache")
-  # RWeka::WPM("install-package", "XMeans")
+  RWeka::WPM("refresh-cache")
+  RWeka::WPM("install-package", "XMeans")
 
   parset.list = list(
     list(),
