@@ -1,5 +1,5 @@
-context("filters")
 
+cat("rankSimpleFilters")
 test_that("base filters of ensemble filters are ranked correctly", {
   requirePackagesOrSkip("Hmisc", default.method = "load")
 
